@@ -10,8 +10,9 @@ from typing import Dict, List
 from requests import get
 from tabulate import tabulate
 from yellowdog_client.common import SearchClient
-from yellowdog_client.common.json import NestedDeserializationError
 from yellowdog_client.model import (
+    Allowance,
+    AllowanceSearch,
     ComputeRequirement,
     ComputeRequirementSearch,
     ComputeRequirementStatus,
@@ -47,7 +48,6 @@ from yd_commands.object_utilities import (
 from yd_commands.printing import (
     CONSOLE_TABLE,
     indent,
-    print_error,
     print_log,
     print_numbered_object_list,
     print_yd_object,
@@ -81,8 +81,10 @@ def main():
         list_keyrings()
     elif ARGS_PARSER.image_families:
         list_image_families()
-    elif ARGS_PARSER.namespaces:
+    elif ARGS_PARSER.namespace_storage_configurations:
         list_namespaces()
+    elif ARGS_PARSER.allowances:
+        list_allowances()
 
 
 def check_for_valid_option() -> bool:
@@ -100,8 +102,9 @@ def check_for_valid_option() -> bool:
         ARGS_PARSER.source_templates,
         ARGS_PARSER.keyrings,
         ARGS_PARSER.image_families,
-        ARGS_PARSER.namespaces,
+        ARGS_PARSER.namespace_storage_configurations,
         ARGS_PARSER.instances,
+        ARGS_PARSER.allowances,
     ].count(True) == 1:
         return True
     else:
@@ -156,7 +159,7 @@ def list_work_requirements():
             CLIENT, work_requirement_summaries, single_result=True
         )
         for work_summary in selected_work_summaries:
-            print_log(f"Work Requirement {work_summary.name}")
+            print_log(f"Work Requirement '{work_summary.name}'")
             list_task_groups(work_summary)
 
 
@@ -408,26 +411,11 @@ def list_source_templates():
         return
 
     cs_templates = select(CLIENT, sorted_objects(cs_templates))
-    deserialisation_failures = []  # Temporary bug workaround
     for cs_template in cs_templates:
-        try:
-            cs_template_detail: ComputeSourceTemplate = (
-                CLIENT.compute_client.get_compute_source_template(cs_template.id)
-            )
-            print_yd_object(cs_template_detail)
-        except NestedDeserializationError:
-            deserialisation_failures.append(
-                f"    Source '{cs_template.name}' ({cs_template.id})"
-            )
-
-    if len(deserialisation_failures) > 0:
-        print_error(
-            "Failed to deserialise the following Source Templates due to the presence"
-            " of User Attributes. This is a temporary issue awaiting an SDK bugfix"
-            " (YEL-12005)."
+        cs_template_detail: ComputeSourceTemplate = (
+            CLIENT.compute_client.get_compute_source_template(cs_template.id)
         )
-        for failure in deserialisation_failures:
-            print_error(failure)
+        print_yd_object(cs_template_detail)
 
 
 def list_keyrings():
@@ -548,6 +536,27 @@ def list_namespaces():
             print_yd_object(namespace)
 
 
+def list_allowances():
+    """
+    List allowances.
+    """
+    allowances_search = AllowanceSearch()
+    search_client: SearchClient = CLIENT.allowances_client.get_allowances(
+        allowances_search
+    )
+    allowances: List[Allowance] = search_client.list_all()
+    if len(allowances) == 0:
+        print_log("No Allowances to display")
+        return
+
+    if not ARGS_PARSER.details:
+        print_numbered_object_list(CLIENT, allowances)
+        return
+
+    for allowance in select(CLIENT, allowances):
+        print_yd_object(allowance)
+
+
 # Entry point
 if __name__ == "__main__":
     main()
