@@ -22,6 +22,7 @@ from yd_commands.settings import (
     ARRAY_TYPE_TAG,
     BOOL_TYPE_TAG,
     ENV_VAR_PREFIX,
+    LOWER_CASE_TYPE_TAG,
     NUMBER_TYPE_TAG,
     RAND_VAR_SIZE,
     TABLE_TYPE_TAG,
@@ -185,7 +186,8 @@ def process_variable_substitutions(
             type_tag = (
                 re.match(
                     f"^{opening_delimiter}({NUMBER_TYPE_TAG}|{BOOL_TYPE_TAG}"
-                    f"|{TABLE_TYPE_TAG}|{ARRAY_TYPE_TAG})(?!{TAG_DEFAULT_DIFF})",
+                    f"|{TABLE_TYPE_TAG}|{ARRAY_TYPE_TAG}|{LOWER_CASE_TYPE_TAG})"
+                    f"(?!{TAG_DEFAULT_DIFF})",
                     element,
                 )
                 .group(0)
@@ -313,6 +315,9 @@ def process_typed_variable_substitution(
     Process a single typed substitution, returning the appropriate type.
     Assumes there is a substitution present.
     """
+    if type_string == LOWER_CASE_TYPE_TAG:
+        return input_string.lower()
+
     if type_string == NUMBER_TYPE_TAG:
         try:
             return int(input_string)
@@ -434,10 +439,12 @@ def load_toml_file_with_variable_substitutions(
     # file as a whole
     try:
         # Convert all values to strings before adding
-        add_substitutions_without_overwriting({
-            var_name: str(var_value)
-            for var_name, var_value in config[COMMON_SECTION][VARIABLES].items()
-        })
+        add_substitutions_without_overwriting(
+            {
+                var_name: str(var_value)
+                for var_name, var_value in config[COMMON_SECTION][VARIABLES].items()
+            }
+        )
     except KeyError:
         pass
 
